==> haskell-libyaml-0.1.1.0-23-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-libyaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: libyaml
version: 0.1.1.0
id: libyaml-0.1.1.0-IKxc4yRro0v1V3qsAflsDo
key: libyaml-0.1.1.0-IKxc4yRro0v1V3qsAflsDo
license: BSD-3-Clause
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov
stability: stable
homepage: https://github.com/snoyberg/yaml#readme
synopsis: Low-level, streaming YAML interface.
description:
    README and API documentation are available at <https://www.stackage.org/package/libyaml>
category: Text
abi: 35544ca9080a8d7fccf61290f265cb69
exposed: True
exposed-modules:
    Text.Libyaml
hidden-modules: Paths_libyaml
import-dirs: /usr/lib/ghc-8.6.5/site-local/libyaml-0.1.1.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/libyaml-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/libyaml-0.1.1.0
hs-libraries: HSlibyaml-0.1.1.0-IKxc4yRro0v1V3qsAflsDo
extra-libraries:
    yaml
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    conduit-1.3.1.1-Hp9wSvoIvGH1D2bMBRqJC
    resourcet-1.2.2-DSV6hnFiraKK5yk15oWe4c
haddock-interfaces: /usr/share/doc/haskell-libyaml/html/libyaml.haddock
haddock-html: /usr/share/doc/haskell-libyaml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-libyaml-0.1.1.0-24-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-libyaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: libyaml
version: 0.1.1.0
id: libyaml-0.1.1.0-LIsN00zw611K6WKast4Hdh
key: libyaml-0.1.1.0-LIsN00zw611K6WKast4Hdh
license: BSD-3-Clause
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov
stability: stable
homepage: https://github.com/snoyberg/yaml#readme
synopsis: Low-level, streaming YAML interface.
description:
    README and API documentation are available at <https://www.stackage.org/package/libyaml>
category: Text
abi: 871c3c9a400c928b1b18eea12afc0de9
exposed: True
exposed-modules:
    Text.Libyaml
hidden-modules: Paths_libyaml
import-dirs: /usr/lib/ghc-8.6.5/site-local/libyaml-0.1.1.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/libyaml-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/libyaml-0.1.1.0
hs-libraries: HSlibyaml-0.1.1.0-LIsN00zw611K6WKast4Hdh
extra-libraries:
    yaml
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    conduit-1.3.1.1-GP6MsgQ2BS48W03o5Iyugz
    resourcet-1.2.2-DSV6hnFiraKK5yk15oWe4c
haddock-interfaces: /usr/share/doc/haskell-libyaml/html/libyaml.haddock
haddock-html: /usr/share/doc/haskell-libyaml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
